@@ -16,7 +16,7 @@
 #' @template section_dictionary_learner
 #'
 #' @references
-#' `r tools::toRd(bibentries["venables_2002"])`
+#' `r format_bib("venables_2002")`
 #'
 #' @export
 #' @template seealso_learner
@@ -73,7 +73,7 @@ LearnerClassifQDA = R6Class("LearnerClassifQDA",
       }
 
       newdata = task$data(cols = task$feature_names)
-      p = mlr3misc::invoke(stats::predict, self$model, newdata = newdata, .args = pars)
+      p = mlr3misc::invoke(predict, self$model, newdata = newdata, .args = pars)
 
       if (self$predict_type == "response") {
         list(response = p$class)
