@@ -10,7 +10,7 @@
 #' @templateVar id classif.ranger
 #'
 #' @references
-#' `r tools::toRd(bibentries[c("wright_2017", "breiman_2001")])`
+#' `r format_bib("wright_2017", "breiman_2001")`
 #'
 #' @export
 #' @template seealso_learner
@@ -122,7 +122,7 @@ LearnerClassifRanger = R6Class("LearnerClassifRanger",
     .predict = function(task) {
       pars = self$param_set$get_values(tags = "predict")
       newdata = task$data(cols = task$feature_names)
-      p = mlr3misc::invoke(stats::predict, self$model,
+      p = mlr3misc::invoke(predict, self$model,
         data = newdata,
         predict.type = "response", .args = pars)
 
