@@ -22,7 +22,7 @@
 #' @templateVar id classif.xgboost
 #'
 #' @references
-#' `r tools::toRd(bibentries["chen_2016"])`
+#' `r format_bib("chen_2016")`
 #'
 #' @export
 #' @template seealso_learner
@@ -223,7 +223,7 @@ LearnerClassifXgboost = R6Class("LearnerClassifXgboost",
 
       newdata = data.matrix(task$data(cols = task$feature_names))
       newdata = newdata[, model$feature_names, drop = FALSE]
-      pred = mlr3misc::invoke(stats::predict, model, newdata = newdata, .args = pars)
+      pred = mlr3misc::invoke(predict, model, newdata = newdata, .args = pars)
 
       if (nlvls == 2L) { # binaryclass
         if (pars$objective == "multi:softprob") {
