@@ -22,7 +22,7 @@
 #' @templateVar id regr.xgboost
 #'
 #' @references
-#' `r tools::toRd(bibentries["chen_2016"])`
+#' `r format_bib("chen_2016")`
 #'
 #' @export
 #' @template seealso_learner
@@ -192,7 +192,7 @@ LearnerRegrXgboost = R6Class("LearnerRegrXgboost",
       model = self$model
       newdata = data.matrix(task$data(cols = task$feature_names))
       newdata = newdata[, model$feature_names, drop = FALSE]
-      response = invoke(stats::predict, model, newdata = newdata, .args = pars)
+      response = invoke(predict, model, newdata = newdata, .args = pars)
 
       list(response = response)
     }
