@@ -3,6 +3,7 @@
 #' @import mlr3misc
 #' @importFrom R6 R6Class
 #' @importFrom mlr3 mlr_learners LearnerClassif LearnerRegr
+#' @importFrom stats predict
 #'
 #' @description
 #' More learners are implemented in the [mlr3extralearners package](https://github.com/mlr-org/mlr3extralearners).
@@ -20,12 +21,13 @@ register_mlr3 = function() {
   x$add("classif.kknn", LearnerClassifKKNN)
   x$add("classif.lda", LearnerClassifLDA)
   x$add("classif.log_reg", LearnerClassifLogReg)
+  x$add("classif.multinom", LearnerClassifMultinom)
   x$add("classif.naive_bayes", LearnerClassifNaiveBayes)
+  x$add("classif.nnet", LearnerClassifNnet)
   x$add("classif.qda", LearnerClassifQDA)
   x$add("classif.ranger", LearnerClassifRanger)
   x$add("classif.svm", LearnerClassifSVM)
   x$add("classif.xgboost", LearnerClassifXgboost)
-  x$add("classif.multinom", LearnerClassifMultinom)
 
   # regression learners
   x$add("regr.cv_glmnet", LearnerRegrCVGlmnet)
@@ -38,10 +40,10 @@ register_mlr3 = function() {
   x$add("regr.xgboost", LearnerRegrXgboost)
 
   # survival learners
-  x$add("surv.glmnet", LearnerSurvGlmnet)
   x$add("surv.cv_glmnet", LearnerSurvCVGlmnet)
-  x$add("surv.xgboost", LearnerSurvXgboost)
+  x$add("surv.glmnet", LearnerSurvGlmnet)
   x$add("surv.ranger", LearnerSurvRanger)
+  x$add("surv.xgboost", LearnerSurvXgboost)
 }
 
 .onLoad = function(libname, pkgname) { # nolint
